@@ -1,5 +1,5 @@
 package Pod::Autopod; ## Generates pod documentation by analysing perl modules.
-$Pod::Autopod::VERSION = '1.204';
+$Pod::Autopod::VERSION = '1.205';
 use 5.006; #Pod::Abstract uses features of 5.6
 use FileHandle;
 use strict;
@@ -314,7 +314,7 @@ my $filename=shift;
 my @f;
 
 	my $fh=new FileHandle;
-	open($fh,$filename);
+	open($fh,'<',$filename);
 		#lockhsh($fh);
 		@f=<$fh>;
 		#unlockh($fh);
@@ -551,7 +551,7 @@ my $file=shift;
 my $text=shift;
 
 	my $fh=new FileHandle;
-	open($fh,">$file");
+	open($fh,'>',"$file");
 #		lockh($fh);
 		print $fh $text;
 #		unlockh($fh);
